/*
   Name:    setupOOo.rex
   Purpose: create a shell script which sets the environment variable CLASSPATH
            to point to the Java archives needed to drive/automate OpenOffice.org
            resp. StarOffice
   Author:  Rony G. Flatscher
   Version: 1.04
   Date:    2006-01-04
   Changed: 2006-01-16, ---rgf, make sure CLASSPATH is used in any case
            2006-01-22, ---rgf, on Linux hint the user how to enter "setEnvironment4BSF4Rexx.sh"

   last change: $Revision: 141 $ $Author: rony $ $Date: 2006-01-22 22:49:47 +0100 (Sun, 22 Jan 2006) $

   license:

    ------------------------ Apache Version 2.0 license -------------------------
       Copyright (C) 2006 Rony G. Flatscher

       Licensed under the Apache License, Version 2.0 (the "License");
       you may not use this file except in compliance with the License.
       You may obtain a copy of the License at

           http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing, software
       distributed under the License is distributed on an "AS IS" BASIS,
       WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
       See the License for the specific language governing permissions and
       limitations under the License.
    -----------------------------------------------------------------------------
*/

cmd.=""                          /* default value for stem        */
parse upper source s +1          /* get first character of operating system in uppercase */
cmd.eIsUnix=(pos(s, "WO")=0)

/* for debugging: force Unix-mode
   cmd.eIsUnix=1
*/

if cmd.eIsUnix=0 then
do
   cmd.eIsUnix=0                 /* Windows/OS2 style       */
   file.sep="\"
   path.sep=";"
end
else
do
   cmd.eIsUnix=1                 /* Unix style              */
   file.sep="/"
   path.sep=":"
end

                                 /* paths to Java and desired bin-dir given?  */
parse arg path2OOo               /* get path to OpenOffice.org/StarOffice     */
oldDir=directory()               /* memorize actual directory                 */
cmd.ePath2OOo=directory(strip(path2OOo, 'B', '"') || file.sep || "program" || file.sep || "classes")

call directory oldDir            /* reset directory                           */
if cmd.ePath2OOo="" then         /* not found, give a message and abort ...   */
do
   say "path to OpenOffice.org/StarOffice directory" pp(path2OOo) "could not be found!"
   say
   say "     usage: rexx setupOOo path-to-OpenOffice-directory"
   say
   if cmd.eIsUnix=0 then
      say '   example: rexx setupOOo d:\Programme\OpenOffice.org 2.0'
   else
      say '   example: rexx setupOOo /opt/openoffice.org.2.0'
   exit -1
end

/* for forcing testing Unix on Windows
j.file.separator="/" -- rgf, debug
j.path.separator=":" -- rgf, debug
*/

cp=value("CLASSPATH", , "ENVIRONMENT") /* try to get the CLASSPATH value   */

if cmd.eIsUnix then
do
   nl="0a"x                      /* Unix new-line character sequence (\n)  */
   cmd.eLeadIn="#!/bin/sh"nl     /* command to execute this file           */
   cmd.eEcho="echo"
   cmd.eSetOOo = "OOoJar=" ||cmd.ePath2OOo
   cmd.eJarVar = path.sep"$OOoJar"file.sep   /* variable to use                        */
   if cp="" then
      cmd.eSetCP  = "CLASSPATH=."            /* make sure local dir is searched!       */
   else
      cmd.eSetCP  = "CLASSPATH=$CLASSPATH"

   cmd.eSetCP2 = "export CLASSPATH"

   cmd.eSetEnvironmentScriptName="setEnvironment4OOo.sh"
   cmd.eSetExecutable    ="chmod +755"   /* set executable for all (user, group, other)  */
   cmd.eLineComment="#"
end
else  /* Windows, OS/2 (eCS), ... */
do
   nl="0d0a"x                    /* Windows/OS2 new-line character sequence (\n) */
   cmd.eEcho="@echo"
   cmd.eSetOOo = 'set OOoJar='cmd.ePath2OOo  /* enquote in case path contains a blank  */
   cmd.eJarVar = path.sep"%OOoJar%"file.sep  /* variable to use                        */
   if cp="" then
      cmd.eSetCP  = "set CLASSPATH=."        /* make sure local dir is searched!       */
   else
      cmd.eSetCP  = "set CLASSPATH=%CLASSPATH%"

   cmd.eSetEnvironmentScriptName="setEnvironment4OOo.cmd"
   cmd.eLineComment="@REM "
end

jars="jurt.jar unoil.jar ridl.jar juh.jar" ,
     "sandbox.jar"               /* only needed for OOo < 2.0              */
do i=1 to words(jars)            /* loop over words                        */
   cmd.eSetCP=cmd.eSetCP || cmd.eJarVar || word(jars, i) /* extract word and append it */
end

/* make sure that CLASSPATH is used in case this script runs at a time, when other programs have set
   the classpath environment variable
*/
if cp="" then
do
  if cmd.eIsUnix=1 then
     cmd.eSetCP=cmd.eSetCP || path.sep || "$CLASSPATH"
  else
     cmd.eSetCP=cmd.eSetCP || path.sep || "%CLASSPATH%"
end

   /* create the script    */
call createScript

call info         /* tell the user what to do with it */

exit

/* create the test script which sets up all needed parameters to run Rexx programs from
   this directory */
createScript: procedure expose cmd.
  fn=cmd.eSetEnvironmentScriptName

  call stream fn, "c", "open replace"
  call lineout fn, cmd.eLeadIn
  call lineout fn, ""
  call lineout fn, cmd.eLineComment "created:" q(date("S") time())
  call lineout fn, cmd.eEcho qe("setting the CLASSPATH environment variable to point to the OpenOffice.org/StarOffice jar files ...")
  call lineout fn, cmd.eLineComment "just run it, before invoking a Rexx program that addresses OpenOffice.org/StarOffice ..."
  call lineout fn, ""

  call lineout fn, cmd.eLineComment "set OOo/SO directory that contains the needed jars..."
  call lineout fn, cmd.eSetOOo
  call lineout fn, ""

  call lineout fn, cmd.eLineComment "set CLASSPATH environment variable ..."
  call lineout fn, cmd.eLineComment "please note: if using OOo/SO version 2.0 or greater, you do not need ""sandbox.jar"""
  call lineout fn, cmd.eSetCP          /* set CLASSPATH        */
  call lineout fn, cmd.eSetCP2         /* export it on Unix    */
  call lineout fn, ""

  call lineout fn, cmd.eEcho qe(".")
  call lineout fn, cmd.eEcho qe("It is advised to add this environment setting to your system's profile!")

  call lineout fn, cmd.eEcho qe("(This way it is always assured, that Rexx can find the OOo Java classes.)")

  call lineout fn, cmd.eEcho qe("E.g. add the following entries to your '~/.bashrc':")
  call lineout fn, cmd.eEcho qe(" ")
  call lineout fn, cmd.eEcho qe("   # allow using OpenOffice.org via its Java interface classes")
  call lineout fn, cmd.eEcho qe("   ." cmd.eSetEnvironmentScriptName ">/dev/null")

  call lineout fn, ""


  call stream fn, "c", "close"

  if cmd.eSetExecutable<>"" then       /* set file executable (Unix)    */
     cmd.eSetExecutable cmd.eSetEnvironmentScriptName

  return



pp: procedure                    /* poor man's "pretty" print     */
  return "[" || arg(1) || "]"


q: procedure                     /* enclose string into apostrophes  */
  return """" || arg(1) || """"

   /* "qe": quote echo string: enquote entire string on Unix only */
qe: procedure expose j. cmd.
  if  cmd.eIsUnix=1 then return """" || arg(1) || """"
                    else return arg(1)


iif: procedure                   /* VBasic-like function          */
  if arg(1)=1 then return arg(2)
  return arg(3)


info:                            /* tell user what has happened   */
  say
  say "the following script has been created:"
  say
  say " " pp(cmd.eSetEnvironmentScriptName)": use to set the environment variable 'CLASSPATH' to"
  say "              point to the OpenOffice.org (OOo)/StarOffice (SO) jar-files"
  say
  if cmd.eIsUnix=0 then
     say "       usage:" cmd.eSetEnvironmentScriptName
  else
     say "       usage:" q(". ./"cmd.eSetEnvironmentScriptName)

  say
  say "     remarks: - After running this script you may invoke any BSF4Rexx-program"
  say "                automating OOo/SO via BSF4Rexx', e.g. (try it!)"
  say
  if cmd.eIsUnix=0 then
     say "                  " cmd.eSetEnvironmentScriptName
  else
     say "                  " q(". ./"cmd.eSetEnvironmentScriptName)

  say "                  " "rexx testOOo.rex"
  say
  say "Good luck! :-)  [You may also want to take a look at this generated script.]"
  exit 0

